aboutsummaryrefslogtreecommitdiffstats
path: root/routers/api/v1/utils/git.go
diff options
context:
space:
mode:
Diffstat (limited to 'routers/api/v1/utils/git.go')
-rw-r--r--routers/api/v1/utils/git.go17
1 files changed, 9 insertions, 8 deletions
diff --git a/routers/api/v1/utils/git.go b/routers/api/v1/utils/git.go
index 32f5c85319..eb82c50544 100644
--- a/routers/api/v1/utils/git.go
+++ b/routers/api/v1/utils/git.go
@@ -69,27 +69,28 @@ func searchRefCommitByType(ctx *context.APIContext, refType, filter string) (str
return "", "", nil
}
-// ConvertToSHA1 returns a full-length SHA1 from a potential ID string
-func ConvertToSHA1(ctx gocontext.Context, repo *context.Repository, commitID string) (git.SHA1, error) {
- if len(commitID) == git.SHAFullLength && git.IsValidSHAPattern(commitID) {
- sha1, err := git.NewIDFromString(commitID)
+// ConvertToObjectID returns a full-length SHA1 from a potential ID string
+func ConvertToObjectID(ctx gocontext.Context, repo *context.Repository, commitID string) (git.ObjectID, error) {
+ objectFormat, _ := repo.GitRepo.GetObjectFormat()
+ if len(commitID) == objectFormat.FullLength() && objectFormat.IsValid(commitID) {
+ sha, err := objectFormat.NewIDFromString(commitID)
if err == nil {
- return sha1, nil
+ return sha, nil
}
}
gitRepo, closer, err := git.RepositoryFromContextOrOpen(ctx, repo.Repository.RepoPath())
if err != nil {
- return git.SHA1{}, fmt.Errorf("RepositoryFromContextOrOpen: %w", err)
+ return objectFormat.Empty(), fmt.Errorf("RepositoryFromContextOrOpen: %w", err)
}
defer closer.Close()
- return gitRepo.ConvertToSHA1(commitID)
+ return gitRepo.ConvertToGitID(commitID)
}
// MustConvertToSHA1 returns a full-length SHA1 string from a potential ID string, or returns origin input if it can't convert to SHA1
func MustConvertToSHA1(ctx gocontext.Context, repo *context.Repository, commitID string) string {
- sha, err := ConvertToSHA1(ctx, repo, commitID)
+ sha, err := ConvertToObjectID(ctx, repo, commitID)
if err != nil {
return commitID
}